summaryrefslogtreecommitdiffstats
path: root/bibletime/backend/cswordkey.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'bibletime/backend/cswordkey.cpp')
-rw-r--r--bibletime/backend/cswordkey.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/bibletime/backend/cswordkey.cpp b/bibletime/backend/cswordkey.cpp
index a1eb360..ccf79bf 100644
--- a/bibletime/backend/cswordkey.cpp
+++ b/bibletime/backend/cswordkey.cpp
@@ -30,7 +30,7 @@
//TQt includes
#include <tqregexp.h>
#include <tqstring.h>
-#include <textcodec.h>
+#include <tqtextcodec.h>
CSwordKey::CSwordKey(CSwordModuleInfo* const module) : m_module(module) {}
@@ -111,9 +111,9 @@ const TQString CSwordKey::renderedText( const CSwordKey::TextRenderType mode ) {
text.replace(
TQRegExp( TQString(
"(>[^<>]+)" // Avoid replacing inside tags
- "\\b(0*%1)\\b").arg(number) ), // And span around 0's
+ "\\b(0*%1)\\b").tqarg(number) ), // And span around 0's
TQString("\\1<span lemma=\"%1%2\"><a href=\"strongs://%3/%4\">\\2</a></span>")
- .arg(langcode, paddednumber, language, paddednumber)
+ .tqarg(langcode, paddednumber, language, paddednumber)
);
pos += rx.matchedLength();
}
@@ -121,8 +121,8 @@ const TQString CSwordKey::renderedText( const CSwordKey::TextRenderType mode ) {
if (mode == HTMLEscaped) {
//we have to encode all UTF-8 in HTML escapes
// go though every character and write down the escaped HTML unicode entity
// form is &#<decimal unicode value here>;
TQString ret;
TQChar c;
const unsigned int length = text.length();
@@ -133,9 +133,9 @@ const TQString CSwordKey::renderedText( const CSwordKey::TextRenderType mode ) {
if (c.latin1()) { //normal latin1 character
ret.append(c);
}
- else {//unicode character, needs to be escaped
+ else {//tqunicode character, needs to be escaped
ret.append("&#")
- .append(c.unicode())
+ .append(c.tqunicode())
.append(";");
}
}
@@ -121,8 +121,8 @@ const TQString CSwordKey::renderedText( const CSwordKey::TextRenderType mode ) {
if (mode == HTMLEscaped) {
//we have to encode all UTF-8 in HTML escapes
- // go though every character and write down the escaped HTML unicode entity
- // form is &#<decimal unicode value here>;
+ // go though every character and write down the escaped HTML tqunicode entity
+ // form is &#<decimal tqunicode value here>;
TQString ret;
TQChar c;